import { ColorMode, ControllerInfo, FontSize, IRectangle, ObjectType, RenderMode, ShuttleMode, TBarResolution, TextRenderOptions } from './protocol';
import { TypedEmitter } from 'tiny-typed-emitter';
export { ObjectType, FontSize, ShuttleMode, ColorMode, ControllerInfo, IRectangle, RenderMode, TBarResolution };
export declare const FullScreen: IRectangle;
export interface JLCSlomoEliteEvents {
    'button': (button: number, down: boolean) => void;
    'jog': (jog: number) => void;
    'shuttle': (pos: number) => void;
    'tbar': (pos: number) => void;
}
export declare class JLCSlomoElite extends TypedEmitter<JLCSlomoEliteEvents> {
    private port;
    private protocol;
    constructor(port: string);
    private openPort;
    open(): Promise<void>;
    clear(): Promise<void>;
    private send;
    requestSystemInfo(): Promise<ControllerInfo>;
    writeText(data: string, options?: TextRenderOptions): Promise<void>;
    setShuttleMode(mode: ShuttleMode): Promise<void>;
    setButtonColor(button: number, color: ColorMode): Promise<void>;
    setTBarResolution(resolution: TBarResolution): Promise<void>;
    drawObject(obj: ObjectType, rect: IRectangle, thickness: number, inverted: boolean): Promise<unknown>;
    setRenderMode(mode: RenderMode): Promise<unknown>;
    requestTransferRAMToDisplay(): Promise<unknown>;
    drawPixels(x: number, y: number, width: number, pixels: Uint8Array): Promise<void>;
}
